LogItem class
Represents a single log item in the logger.
Constructors
- LogItem({required LogItemType type, String? title, required String description})
- Creates a new log item with the specified type, description, and optional title.
Properties
- description → String
-
The main content/description of the log.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- time ↔ DateTime
-
The timestamp when the log item is created.
latefinal
- title → String?
-
An optional title for the log item.
final
- type → LogItemType
-
The type of the log (info, success, warning, error).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited