OnScreenLog class
This class provides an interface for logging messages to an on-screen logger.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
clearAll(
) → void - Clears all logged messages.
-
e(
{String? title, required String message}) → void - Logs an error message.
-
i(
{String? title, required String message}) → void - Logs an informational message.
-
onError(
) → void - Sets up error handling to log Flutter errors automatically.
-
s(
{String? title, required String message}) → void - Logs a success message.
- Shares all logged messages.
-
w(
{String? title, required String message}) → void - Logs a warning message.