OnscreenLogger class
This class provides an interface for logging messages to an on-screen logger.
It has been marked as Deprecated and should be replaced with ScreenLog.
Use this class to log messages, handle Flutter errors, or initialize the logger overlay.
- Annotations
-
- @Deprecated('Use ScreenLog instead!')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited